==> speech-analytic-testing_3.5.5_database.tar.gz: database/mssql/procedures/GetAuditorEvaluationPlanEvaluation.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAuditorEvaluationPlanEvaluation] (
	@Instance Varchar(50) = NULL,
	@AuditorId Varchar(50) = NULL,
	@EvaluationPlanId Varchar(50) = NULL,
	@InteractionId Varchar(250) = NULL,
	@InteractionType Varchar(25) = NULL,
	@EfectivityPlanId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	IF (ISNULL(@EfectivityPlanId,'') = '' OR @EfectivityPlanId = '' )
	BEGIN

		SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
				EP.[Evaluation_Mode]				'evaluation_mode',
				AEP.[IdAuditor]						'auditorId', 
				IEP.[IdAgent]						'agentId',
				IEP.[AgentName]						'agentName',
				AEP.[IdInteraction]					'interactionId', 
				AEP.[Completed]						'evaluationCompleted', 
				EP.[Description]					'evaluationPlanDescription',
				EP.[IdEvaluationFormat]				'evaluationFormatId',
				AEP.[Completed]						'completed',
				AEP.[Status]						'status',
				AEP.[StatusDescription]				'statusDescription'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.ID = AEP.IdEvaluationPlan
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[InteractionType] = AEP.[InteractionType]
					AND IEP.[IdAgent] = AEP.[IdAgent]		
			WHERE AEP.[Instance] = @Instance 
				AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
				AND AEP.[IdAuditor] = @AuditorId 
				AND AEP.[IdInteraction] = @InteractionId
				AND AEP.[InteractionType] = @InteractionType;
		END
	ELSE
		BEGIN
		
		SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
				ERE.[EfectivityPlanId]				'efectivityPlanId',
				EP.[Evaluation_Mode]				'evaluation_mode',
				ERE.[AuditorId]					    'auditorId', 
				IEP.[IdAgent]						'agentId',
				IEP.[AgentName]						'agentName',
				AEP.[IdInteraction]					'interactionId', 
				AEP.[Completed]						'evaluationCompleted', 
				EP.[Description]					'evaluationPlanDescription',
				EP.[IdEvaluationFormat]				'evaluationFormatId',
				AEP.[Completed]						'completed',
				AEP.[Status]						'status',
				AEP.[StatusDescription]				'statusDescription'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.ID = AEP.IdEvaluationPlan
			INNER JOIN (SELECT DISTINCT [VCC],[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
						WHERE EfectivityPlanId = @EfectivityPlanId AND AuditorId = @AuditorId
			) AS ERE
			ON AEP.[Instance] = ERE.[VCC]
			AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
			AND AEP.[IdInteraction] = [ERE].[InteractionId]			

			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[InteractionType] = AEP.[InteractionType]
					AND IEP.[IdAgent] = AEP.[IdAgent]		
			WHERE AEP.[Instance] = @Instance 
				AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
				AND ERE.[AuditorId] = @AuditorId 
				AND AEP.[IdInteraction] = @InteractionId
				AND AEP.[InteractionType] = @InteractionType;

		END


	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetAuditorEvaluationPlanEvaluation.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAuditorEvaluationPlanEvaluation] (
	@Instance Varchar(50) = NULL,
	@AuditorId Varchar(50) = NULL,
	@EvaluationPlanId Varchar(50) = NULL,
	@InteractionId Varchar(250) = NULL,
	@InteractionType Varchar(25) = NULL,
	@EfectivityPlanId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	IF ISNULL(@EfectivityPlanId, '') = '' 
	BEGIN
		-- 
		SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
				EP.[Evaluation_Mode]				'evaluation_mode',
				AEP.[IdAuditor]						'auditorId', 
				IEP.[IdAgent]						'agentId',
				IEP.[AgentName]						'agentName',
				AEP.[IdInteraction]					'interactionId', 
				AEP.[Completed]						'evaluationCompleted', 
				EP.[Description]					'evaluationPlanDescription',
				EP.[IdEvaluationFormat]				'evaluationFormatId',
				AEP.[Completed]						'completed',
				AEP.[Status]						'status',
				AEP.[StatusDescription]				'statusDescription'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan]
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[InteractionType] = AEP.[InteractionType]
					AND (
						IEP.[IdAgent] = AEP.[IdAgent]
						OR
						ISNULL(IEP.[IdAgent], '') = ISNULL(AEP.[IdAgent], '')
					)
			WHERE AEP.[Instance] = @Instance 
				AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
				AND AEP.[IdAuditor] = @AuditorId 
				AND AEP.[IdInteraction] = @InteractionId
				AND AEP.[InteractionType] = @InteractionType
	END
	ELSE
	BEGIN
		SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
				ERE.[EfectivityPlanId]				'efectivityPlanId',
				EP.[Evaluation_Mode]				'evaluation_mode',
				ERE.[AuditorId]					    'auditorId', 
				IEP.[IdAgent]						'agentId',
				IEP.[AgentName]						'agentName',
				AEP.[IdInteraction]					'interactionId', 
				AEP.[Completed]						'evaluationCompleted', 
				EP.[Description]					'evaluationPlanDescription',
				EP.[IdEvaluationFormat]				'evaluationFormatId',
				AEP.[Completed]						'completed',
				AEP.[Status]						'status',
				AEP.[StatusDescription]				'statusDescription'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.ID = AEP.IdEvaluationPlan
			INNER JOIN (SELECT DISTINCT [VCC],[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
						WHERE EfectivityPlanId = @EfectivityPlanId AND AuditorId = @AuditorId
			) AS ERE
			ON AEP.[Instance] = ERE.[VCC]
			AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
			AND AEP.[IdInteraction] = [ERE].[InteractionId]			

			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[InteractionType] = AEP.[InteractionType]
					AND (
						IEP.[IdAgent] = AEP.[IdAgent]
						OR
						ISNULL(IEP.[IdAgent], '') = ISNULL(AEP.[IdAgent], '')
					)
			WHERE AEP.[Instance] = @Instance 
				AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
				AND ERE.[AuditorId] = @AuditorId 
				AND AEP.[IdInteraction] = @InteractionId
				AND AEP.[InteractionType] = @InteractionType;

		END


	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
